@@ -119,11 +119,7 @@ class ViewsContainer:
             Get view for current playlist
             @return View
         """
-        if App().player.queue and not view_type & ViewType.FULLSCREEN:
-            from lollypop.view_queue import QueueView
-            view = QueueView(view_type | self._view_type)
-            view.populate()
-        elif App().player.playlist_ids:
+        if App().player.playlist_ids:
             from lollypop.view_playlists import PlaylistsView
             view = PlaylistsView(App().player.playlist_ids,
                                  view_type | self._view_type)
